@@ -1,6 +1,6 @@
 import socket
-from Parser import parse_to_python_object
-from Errors import FailedLogin, ConnectionTimeOut, CommandFailedError
+from CGPCLI.Parser import parse_to_python_object
+from CGPCLI.Errors import FailedLogin, ConnectionTimeOut, CommandFailedError
 
 class CGPConnector:
     def __init__(self, host, port=106):
