@@ -4,7 +4,7 @@ from ipaddress import ip_address
 from datetime import datetime
 import xml.etree.ElementTree as ET
 
-from Errors import NotValidCGPStringError
+from CGPCLI.Errors import NotValidCGPStringError
 
 class IP():
     def __init__(self, ip, port=None):
@@ -84,7 +84,7 @@ def parse_to_python_object(string):
             sert, src = match.groups()
             yield sert, src
 
-    quoted_regex = re.compile(r"\"(.*?)(?:(?<!\\)\"|\"$|;)(.*)", re.DOTALL)#r"\"(.*?(?<!\\))\"(.*)"     \"(.*?(?:\"\b.+)?)\"(.*)
+    quoted_regex = re.compile(r"\"(.*?)(?:(?<!\\)\"|\"(?=$|; ?(?:\"|})))(.*)", re.DOTALL)#r"\"(.*?(?<!\\))\"(.*)"     \"(.*?(?:\"\b.+)?)\"(.*)    \"(.*?)(?:(?<!\\)\"|\"$)(.*)
     unquoted_regex = re.compile(r"([\w.@#-]+)(.*)", re.DOTALL)
 
     def parse_string(src):
